@@ -16,8 +16,9 @@ from rmtoo.lib.InputModuleTypes import InputModuleTypes
 
 class RDepDependsOn(Digraph.Node):
     '''This class handles the creation of the full directed
-       graphs: one 'Depends on' and one 'Dependent'.
-       Both graphs are digraphs.'''
+    graphs: one 'Depends on' and one 'Dependent'.
+    Both graphs are digraphs.
+    '''
 
     depends_on = []
     tag = "Depends on"
@@ -26,10 +27,13 @@ class RDepDependsOn(Digraph.Node):
         Digraph.Node.__init__(self, "RDepDependsOn")
         self.config = config
 
-    def get_type_set(self):
+    @staticmethod
+    def get_type_set():
+        """Return the requirement's types"""
         return set([InputModuleTypes.reqdeps, ])
 
     def rewrite(self, reqset):
+        """Change the requirement set based on 'Depends on'"""
         conf_dependency_notation = \
             self.config.get_value('requirements.input.dependency_notation')
         if self.tag not in conf_dependency_notation:
