@@ -15,19 +15,21 @@ from rmtoo.lib.InputModuleTypes import InputModuleTypes
 
 
 class ReqClass(ReqTagGeneric):
+    """Class Tag"""
 
     def __init__(self, config):
         ReqTagGeneric.__init__(self, config, "Class",
                                set([InputModuleTypes.reqtag, ]))
 
     def rewrite(self, rid, req):
-        # This tag (Class) is mandatory optional
-        # (which means: if it's not there, there is a default - but
-        # every requirement do own one class)
+        """This tag (Class) is mandatory optional
+        (which means: if it's not there, there is a default - but
+        every requirement do own one class)
+        """
         if self.get_tag() not in req:
-            v = ClassTypeDetailable()
+            val = ClassTypeDetailable()
         else:
-            t = req[self.get_tag()].get_content()
-            v = create_class_type(rid, t)
+            tcontent = req[self.get_tag()].get_content()
+            val = create_class_type(rid, tcontent)
             del req[self.get_tag()]
-        return self.get_tag(), v
+        return self.get_tag(), val
