@@ -14,6 +14,7 @@ from rmtoo.lib.InputModuleTypes import InputModuleTypes
 
 
 class ReqName(ReqTagGeneric):
+    """Name attribute"""
 
     def __init__(self, config):
         ReqTagGeneric.__init__(
@@ -22,6 +23,6 @@ class ReqName(ReqTagGeneric):
                  InputModuleTypes.testcase]))
 
     def rewrite(self, rid, req):
-        # This tag (Name) is mandatory
+        """This tag (Name) is mandatory"""
         self.check_mandatory_tag(rid, req, 37)
         return self.get_and_remove(req)
